function [r,tau,phir,phitau]=factrtau(obj)
% FACTRTAU returns the factors of reflection and transmission in terms of 
%   wavefunction complex amplitudes of a physical object which interacts 
%   with a step of potential energy. 
%   The phase (phi) of these complex factors are given between 0 and 2*pi.
%
%   [r,tau,phir,phitau]=factrtau(obj)
%       >> obj      = Step object
%       << r        = Factor of reflection
%       << tau      = Factor of transmission
%       << phir     = Phase at reflection
%       << phitau   = Phase at transmission
%
%   Olivier Pujol (2010)
%
%
%% Verifications

if (isa(obj,'step')==0),error('Bad object type!');end
if (obj.ke==0),error('Singular case k=0 !');end

%% Step matrix 

mat=matrix(obj);

%% Computing of factors r and tau

r=-mat(2,1)/mat(2,2);
tau=sqrt(obj.ke/obj.ks)*(1/mat(2,2));
%
phir=mod(angle(r),pi);
phitau=mod(angle(tau),pi);
%
return;