function graph(obj,x,rho)
% GRAPH plots a step of potential energy and the probability density of a
%   physical object which interacts with the considered (drawn) step. 
%
%   graph(obj,x,rho)
%       >> obj      = Step object
%       >> x        = Variable of position on Ox axis
%       >> rho      = Probability density
%
%   Olivier Pujol (2010)
%
%% Verifications

if (isa(obj,'step')==0),error('Bad object type!');end
%
xmin=x{1}(1);
xmax=x{2}(end);
if ( (xmin>=obj.x)||(xmax<=obj.x) ),error('The step is out of domain!');end
Epmin=min(obj.Epe,obj.Eps);
Epmax=max(obj.Epe,obj.Eps);

%% Graph

figure

subplot(2,1,1);
hs=stairs([xmin obj.x xmax],[obj.Epe obj.Eps obj.Eps]);
set(hs,'LineWidth',2,'Color','b');grid on;box on;
axis([xmin xmax Epmin-.2 Epmax+.2]);
grid on;
box on;
set(gca,'Xminortick','on','Yminortick','on');
xlabel('{\itx} (nm)');
ylabel('Potential energy (eV)');
%
subplot(2,1,2);
hp=plot(x{1},rho{1},x{2},rho{end});
set(hp,'LineWidth',2,'Color','r');
axis auto;
grid on;
box on;
set(gca,'Xminortick','on','Yminortick','on');
xlabel('{\itx} (nm)');
ylabel('{|\it\psi |^{2}}');
%
return;