function obj=set(obj,varargin)
% SET returns a new step obtained by modifying one or some 
%   values of the property of a previous step.
%
%   obj=set(obj,property1,value1,property2,value2,...) 
%					-- varargin states for various input arguments.
%       >> obj          = Step object
%       >> property     = Step property
%       >> value        = Property value
%
%   Property =   %'Name','Position','InputPotentialEnergy','OutputPotentialEnergy', 
%                 'InputWaveVector', 'OutputWaveVector'
%
%       << obj          = New step object
%
%   Olivier Pujol (2010)
%
prop_argin=varargin;
while length(prop_argin)>=2
    property=prop_argin{1};
    value=prop_argin{2};
    prop_argin=prop_argin(3:end);
    switch property
        case 'Name'
            obj.name=value;
        case 'Position'
            obj.x=value;
        case 'InputPotentialEnergy'
            obj.Epe=value;
        case 'OutputPotentialEnergy'
            obj.Eps=value;
        case 'InputWaveVector'
            obj.ke=value;
        case 'OutputWaveVector'
            obj.ks=value;
        otherwise
            error([property,' is not a step property!']);
    end
end

return;