function sys=System(varargin)
% System returns a matrix structure where each cell contains the characteristics  
% 	of the elementary potential energies which constitute the whole potential 
%	energy, and the wavevectors (input and output) of the physical object. 
%   The system is: {potential energy - physical object}.
%
%   sys=System(varargin) -- varargin states for various input arguments.
%       >> varargin 	= Elementary potential energies (variable number)
%       << sys 			= System
%
%   The elementary potential energies must be written following the order for 
%	which they are "encountered" by the physical object.
%
%   Olivier Pujol (2010)
%
if (nargin<1), error('Bad number of input arguments!');end
%
sys=cell(1,length(varargin));   % Initialization
%
for k=1:length(varargin)
    sys{k+1}=varargin{k};
end
sys{1}=[get(varargin{1},'InputPotentialEnergy') ...
        get(varargin{end},'OutputPotentialEnergy') ...
        get(varargin{1},'InputWaveVector') ...
        get(varargin{end},'OutputWaveVector') ...
        get(varargin{1},'Position') ...
        get(varargin{end},'Position')];
%
return;