function [R,T]=factRT(sys,TES)
% FactRT returns the reflection and transmission probabilities of a physical 
%   object which interacts with a potential energy.
%
%   [R,T]=FactRT(sys,TES)
%       >> sys  = System
%       >> TES  = Transfer matrix of the system
%       << R    = Probability of reflection
%       << T    = Probability of transmission
%
% Olivier Pujol (2010)

if (nargin<1), error('Bad number of input arguments!');end

nE=size(TES,2); % Number of energy values
R=nan(1,nE);
T=nan(1,nE);

for iE=1:nE
    if ( (isreal(sys{iE}{1}(3))==1)&&(isreal(sys{iE}{1}(4))==1) )
        R(iE)=(abs(-TES{iE}(2,1)/TES{iE}(2,2)))^2;
        T(iE)=(1/abs(TES{iE}(2,2)))^2;
    end
%
    if ( (isreal(sys{iE}{1}(3))==1)&&(isreal(sys{iE}{1}(4))==0) )
        R(iE)=1;
        T(iE)=0;
    end
%
end

return;