function graph(sys,x,rho)
% GRAPH plots the potential energy and the probability density of a 
%   physical object. 
%
%   graph(sys,x,rho)
%       >> sys 	= System
%       >> x 	= Spatial variable (coordinate on Ox axis)
%       >> rho 	= Probability density
%
%   Olivier Pujol (2010)
%
%% Verifications

if (nargin~=3);error('Bad number of input arguments!');end
if (isa(sys,'cell')==0),error('First argument must be of type ''cell'' !');end

%% Plotting

figure
subplot(2,1,1)
plotsys(sys,x);
subplot(2,1,2);
plot_rho(x,rho);
%
return;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function plotsys(sys,x)
%
if (nargin~=2),error('Bad number of input arguments!');end
%
xmin=x{1}(1);
xmax=x{end}(end);

if ( xmin>sys{1}{1}(5) || xmax<sys{1}{1}(6) )
    error('System is out of domain!');
end
%
%   Position and value of potential energies for the first energy value are required (sys{1}). 
%   It is equal for the other values of the energy. 

pos=nan(1,length(sys{1})-1);    % Initialization
Ep=nan(1,length(sys{1})-1);     % Initialization
%
for i=2:length(sys{1})
    if (isa(sys{1}{i},'step')==0),error('Bad argument type!');end
    pos(i-1)=get(sys{1}{i},'Position');
    Ep(i-1)=get(sys{1}{i},'OutputPotentialEnergy');
end
%
pos=[xmin pos xmax];
Ep_e=sys{1}{1}(1);
Ep_s=sys{1}{1}(2);
Ep=[Ep_e Ep Ep_s];
%
hs=stairs(pos,Ep);
set(hs,'LineWidth',2,'Color','b');
axis([xmin xmax min(Ep)-0.2*max(Ep) max(Ep)+0.2*max(Ep)]);
grid on;
box on
xlabel('{\itx} (nm)');
title('{Potential energy (eV)}');
%
return;
%
function plot_rho(x,rho)
%
if (nargin~=2),error('Bad number of input argument!');end
%
for i=1:length(x)
    plot(x{i},rho{i},'LineWidth',2,'Color','r');
    hold on;
end
axis tight;
grid on;
box on;
xlabel('{\itx} (nm)');
title('{|\it{\psi}|^{2}}');
%
return;
