 function graphe3D(M,xt,Ep,m,E,para)
% graphe3D plots the transmission probability T versus energy E and an user- 
%  chosen parameter. 
%
%   graphe3D(M,xt,Ep,m,E,para)
%       >> M 	= Step names
%       >> xt 	= Step positions 
%       >> Ep 	= Potential energy values
%       >> m 	= Physical object mass (with respect to electron mass) 
%       >> E 	= Physical object energy values
%       >> para 	= Values of the parameter chosen by the user
%
% Olivier Pujol (2010)
%

iconf=input('Bound states: no (chose 0) / yes (chose 1) ?');
im=input('What is the considered step gate? ');
type=input('Parameter chosen for the step: width (chose 1) / height (chose 2) :');

% Must the step following the considered step (im) be translated?
if type==1 && size(xt,2)>2
    decale=input('Translation of the step following the considered step: no (chose 0) / yes (chose 1) :');
end
if (size(xt,2)<3),decale=0;end     % Case of one barrier/well

% Verification
if (im > length(xt)) || (im < 1) 
    disp(' ');
    disp(['Gate step', num2str(im),'does not exist!']);
    disp(['One must  have 1 <= im <= ', num2str(length(xt)),' ! ']);
    disp(' ');
    return;
end

% For each value of the parameter, system must be calculated, then the 
% transfert matrix and finally R and T factors. 

R=nan(length(E),length(para));      % Initialization
if (iconf==0)
    T=nan(length(E),length(para));  % T-initialization (scattering states)
else
    d=nan(length(E),length(para));  % d-initialization (Bound states)
end

switch type
    case 1    % Parameter considered is step position
        
        if (para(1)<=xt(im-1))
            error('The minimal value of the parameter is lower or equal to the previous step position!');
        end

        xt=repmat(xt,length(para),1);   % Row vector xt replication. 

        switch decale
            case 0      % Successive matrices are not translated
                if (para(end)>=xt(im+1) && size(xt,2)>=3)
                    error('The maximam value of the parameter is greater or equal to the following step position!');
                end
                xt(:,im)=para'; % New matrix xt
                
            case 1      % Successive matrices are translated
                delta=para'-xt(1,im);
                for i=im:size(xt,2)
                    xt(:,i)=xt(:,i)+delta;  % New matrix xt
                end                
        end
                
        for ipara=1:length(para)
            [sys]=Epot(M,xt(ipara,:),Ep,m,E);
            TES=matrix(sys);
            switch iconf
                case 0
                [R(1:length(sys),ipara),T(1:length(sys),ipara)]=factRT(sys,TES);
                case 1
                d(1:length(sys),ipara)=Calc_d(TES);
            end
        end
        
    case 2    % Parameter considered is height step 
              % (Careful: gate step 1 --> gate height step 2
        
        Ep=repmat(Ep,length(para),1);
        Ep(:,im+1)=para';
        
        for ipara=1:length(para)
            [sys,E]=Epot(M,xt,Ep(ipara,:),m,E);
            TES=matrix(sys);
            switch iconf
                case 0
                [R(1:length(sys),ipara),T(1:length(sys),ipara)]=factRT(sys,TES);
                case 1
                d(1:length(sys),ipara)=Calc_d(TES);
            end
        end       
end

clear TES sys

% Figure
figure
if (iconf==0),surf(para,E,T);end              	% Plotting can be surf or mesh, etc.). Cf. Matlab documentation
if (iconf==1),surf(para,E,log(abs(d)));end      % Idem
shading interp;
colormap('jet');
colorbar('vertical');
if (type==1);xlabel(['Step position',num2str(im),' (nm) ']);end
if (type==2);xlabel(['Step height',num2str(im),' (eV) ']);end
ylabel('Energy  (eV)');
if (iconf==0),title('Transmission factor');end
if (iconf==1),title('Absolute value of d-logarithm (matrix abcd)');end
axis tight

return;

function d=Calc_d(TES)

d=nan(1,length(TES));   % Initialiwation

for i=1:size(TES,2)
    d(i)=TES{i}(2,2);   % d element
end

return;